@@ -66,9 +66,9 @@ class TimeRow(AbstractData):
     def load_arrays(self, row, time):
         if len(row) != len(time):
             raise ValueError('row and time must have the same length')
-        self.raw_data = row
-        self.time_var = time
-        self.values = row
+        self.raw_data = numpy.asarray(row)
+        self.time_var = numpy.asarray(time)
+        self.values = numpy.asarray(row)
         self.n = len(self.time_var)
 
     def __str__(self):
